// Copyright 2006 Nokia Corporation.
//
// THIS SOURCE CODE IS PROVIDED 'AS IS', WITH NO WARRANTIES WHATSOEVER,
// EXPRESS OR IMPLIED, INCLUDING ANY WARRANTY OF MERCHANTABILITY, FITNESS
// FOR ANY PARTICULAR PURPOSE, OR ARISING FROM A COURSE OF DEALING, USAGE
// OR TRADE PRACTICE, RELATING TO THE SOURCE CODE OR ANY WARRANTY OTHERWISE
// ARISING OUT OF ANY PROPOSAL, SPECIFICATION, OR SAMPLE AND WITH NO
// OBLIGATION OF NOKIA TO PROVIDE THE LICENSEE WITH ANY MAINTENANCE OR
// SUPPORT. FURTHERMORE, NOKIA MAKES NO WARRANTY THAT EXERCISE OF THE
// RIGHTS GRANTED HEREUNDER DOES NOT INFRINGE OR MAY NOT CAUSE INFRINGEMENT
// OF ANY PATENT OR OTHER INTELLECTUAL PROPERTY RIGHTS OWNED OR CONTROLLED
// BY THIRD PARTIES
//
// Furthermore, information provided in this source code is preliminary,
// and may be changed substantially prior to final release. Nokia Corporation
// retains the right to make changes to this source code at
// any time, without notice. This source code is provided for informational
// purposes only.
//
// Nokia and Nokia Connecting People are registered trademarks of Nokia
// Corporation.
// Java and all Java-based marks are trademarks or registered trademarks of
// Sun Microsystems, Inc.
// Other product and company names mentioned herein may be trademarks or
// trade names of their respective owners.
//
// A non-exclusive, non-transferable, worldwide, limited license is hereby
// granted to the Licensee to download, print, reproduce and modify the
// source code. The licensee has the right to market, sell, distribute and
// make available the source code in original or modified form only when
// incorporated into the programs developed by the Licensee. No other
// license, express or implied, by estoppel or otherwise, to any other
// intellectual property rights is granted herein.
package bcexchanger.ui;

import javax.microedition.lcdui.CommandListener;
import javax.microedition.lcdui.Display;
import javax.microedition.lcdui.Displayable;

import bcexchanger.*;

/**
 * 
 * This class is an abstract base class for all the UI screen in this
 * application. This class implements CommandListner interface.
 * 
 * @version 1.0 29.09.2005
 * @see example.BCExchanger.ui.Screen Design patterns: State
 * 
 */
public abstract class Screen implements CommandListener {

  protected BCExchangerMIDlet midlet;
  protected Displayable displayable;

  /**
   * Constructor
   * 
   * @param _midlet -
   *          the parent class which keeps the current UI state
   */
  public Screen(BCExchangerMIDlet _midlet) {
    midlet = _midlet;
  }

  /**
   * Makes current screen active
   * <p>
   * Each class inherited from Screen has a displayable associated.
   * When this method is called the displayble is made visiable and
   * active
   * 
   */
  public void makeActive() {
    try {
      Display d = Display.getDisplay(midlet);

      if (d.getCurrent() != displayable) { // this prevents from
                                            // bringing application to
                                            // foreground in case is
                                            // application is in
                                            // background and the
                                            // current displayable is
                                            // the same as the one
                                            // made active
        d.setCurrent(displayable);
      }

    } catch (NullPointerException e) {
      throw new RuntimeException(
          "Internal error #2: Screen.midlet == null");
    }
  }

}
