// Copyright 2006 Nokia Corporation.
//
// THIS SOURCE CODE IS PROVIDED 'AS IS', WITH NO WARRANTIES WHATSOEVER,
// EXPRESS OR IMPLIED, INCLUDING ANY WARRANTY OF MERCHANTABILITY, FITNESS
// FOR ANY PARTICULAR PURPOSE, OR ARISING FROM A COURSE OF DEALING, USAGE
// OR TRADE PRACTICE, RELATING TO THE SOURCE CODE OR ANY WARRANTY OTHERWISE
// ARISING OUT OF ANY PROPOSAL, SPECIFICATION, OR SAMPLE AND WITH NO
// OBLIGATION OF NOKIA TO PROVIDE THE LICENSEE WITH ANY MAINTENANCE OR
// SUPPORT. FURTHERMORE, NOKIA MAKES NO WARRANTY THAT EXERCISE OF THE
// RIGHTS GRANTED HEREUNDER DOES NOT INFRINGE OR MAY NOT CAUSE INFRINGEMENT
// OF ANY PATENT OR OTHER INTELLECTUAL PROPERTY RIGHTS OWNED OR CONTROLLED
// BY THIRD PARTIES
//
// Furthermore, information provided in this source code is preliminary,
// and may be changed substantially prior to final release. Nokia Corporation
// retains the right to make changes to this source code at
// any time, without notice. This source code is provided for informational
// purposes only.
//
// Nokia and Nokia Connecting People are registered trademarks of Nokia
// Corporation.
// Java and all Java-based marks are trademarks or registered trademarks of
// Sun Microsystems, Inc.
// Other product and company names mentioned herein may be trademarks or
// trade names of their respective owners.
//
// A non-exclusive, non-transferable, worldwide, limited license is hereby
// granted to the Licensee to download, print, reproduce and modify the
// source code. The licensee has the right to market, sell, distribute and
// make available the source code in original or modified form only when
// incorporated into the programs developed by the Licensee. No other
// license, express or implied, by estoppel or otherwise, to any other
// intellectual property rights is granted herein.
package bcexchanger.ui;

import java.util.Enumeration;
import java.util.Vector;

import javax.microedition.lcdui.Choice;
import javax.microedition.lcdui.Command;
import javax.microedition.lcdui.Displayable;
import javax.microedition.lcdui.List;

import bcexchanger.*;

/**
 * 
 * This class implements the service list screen. This screen is used
 * to when several services are available in vicinity and allows user
 * to choose the desired one. Using this screen user can select the
 * service or cancel the processs
 * 
 * The class is extending an example.BCExchanger.ui.Screen class
 * 
 * @version 1.0 29.09.2005
 * @see example.BCExchanger.ui.Screen Design patterns: State
 * 
 */
public class ServiceListScreen extends Screen {

  private List list;
  private Command okCommand;
  private Command cancelCommand;

  /**
   * Constructor
   * 
   * @param _midlet -
   *          the parent class which keeps the current UI state
   * @param friendlyNames -
   *          vector of the friednly names of the devices which
   *          contain the services
   */
  public ServiceListScreen(BCExchangerMIDlet _midlet,
      Vector friendlyNames) {
    super(_midlet);

    list = new List("Choose service", Choice.EXCLUSIVE);

    if (friendlyNames.isEmpty()) {
      // list should not be empty
      throw new RuntimeException("Internal error #23");
    }

    Enumeration e = friendlyNames.elements();

    while (e.hasMoreElements()) {
      list.append((String) e.nextElement(), null);
    }

    okCommand = new Command("Ok", Command.OK, 1);
    cancelCommand = new Command("Cancel", Command.CANCEL, 1);

    list.addCommand(okCommand);
    list.addCommand(cancelCommand);

    list.setCommandListener(this);

    displayable = list;
  }

  public void commandAction(Command command, Displayable _displayable) {
    if (_displayable != list) {
      // wrong displayable
      throw new RuntimeException("Internal error #24");
    }

    if (command == okCommand) {
      midlet.serviceSelected(list.getSelectedIndex());
      midlet.unblock();
    } else if (command == cancelCommand) {
      midlet.getExchanger().cancelSending();
      midlet.unblock();
    } else {
      // unknown command
      throw new RuntimeException("Internal error #25");
    }

  }
}
